@@ -13,6 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from octavia_lib.api.drivers import data_models as driver_dm
+from octavia_lib.common import constants as lib_consts
 from oslo_config import cfg
 from oslo_db import exception as odb_exceptions
 from oslo_log import log as logging
@@ -22,7 +24,6 @@ from pecan import request as pecan_request
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
 
-from octavia.api.drivers import data_models as driver_dm
 from octavia.api.drivers import driver_factory
 from octavia.api.drivers import utils as driver_utils
 from octavia.api.v2.controllers import base
@@ -33,6 +34,7 @@ from octavia.common import data_models
 from octavia.common import exceptions
 from octavia.common import stats
 from octavia.common import utils as common_utils
+from octavia.common import validate
 from octavia.db import api as db_api
 from octavia.db import prepare as db_prepare
 from octavia.i18n import _
@@ -46,7 +48,7 @@ class ListenersController(base.BaseController):
     RBAC_TYPE = constants.RBAC_LISTENER
 
     def __init__(self):
-        super(ListenersController, self).__init__()
+        super().__init__()
 
     @wsme_pecan.wsexpose(listener_types.ListenerRootResponse, wtypes.text,
                          [wtypes.text], ignore_extra_args=True)
@@ -174,12 +176,13 @@ class ListenersController(base.BaseController):
             self._validate_insert_headers(
                 listener_dict['insert_headers'].keys(), listener_protocol)
 
-        # Check for UDP compatibility
-        if (listener_protocol == constants.PROTOCOL_UDP and
+        # Check for UDP/SCTP compatibility
+        if (listener_protocol in (constants.PROTOCOL_UDP,
+                                  lib_consts.PROTOCOL_SCTP) and
                 self._is_tls_or_insert_header(listener_dict)):
             raise exceptions.ValidationException(
                 detail=_("%s protocol listener does not "
-                         "support TLS.") % constants.PROTOCOL_UDP)
+                         "support TLS.") % listener_protocol)
 
         # Check for TLS disabled
         if (not CONF.api_settings.allow_tls_terminated_listeners and
@@ -228,6 +231,15 @@ class ListenersController(base.BaseController):
                 "A client authentication CA reference is required to "
                 "specify a client authentication revocation list."))
 
+        # Check TLS cipher prohibit list
+        if 'tls_ciphers' in listener_dict and listener_dict['tls_ciphers']:
+            rejected_ciphers = validate.check_cipher_prohibit_list(
+                listener_dict['tls_ciphers'])
+            if rejected_ciphers:
+                raise exceptions.ValidationException(detail=_(
+                    'The following ciphers have been prohibited by an '
+                    'administrator: ' + ', '.join(rejected_ciphers)))
+
         # Validate the TLS containers
         sni_containers = listener_dict.pop('sni_containers', [])
         tls_refs = [sni['tls_container_id'] for sni in sni_containers]
@@ -241,8 +253,8 @@ class ListenersController(base.BaseController):
                 listener_dict.get('client_ca_tls_certificate_id'),
                 listener_dict.get('client_crl_container_id', None))
 
-        # Validate that the L4 protocol (UDP or TCP) is not already used for
-        # the specified protocol_port in this load balancer
+        # Validate that the L4 protocol (UDP, TCP or SCTP) is not already used
+        # for the specified protocol_port in this load balancer
         pcontext = pecan_request.context
         query_filter = {
             'project_id': listener_dict['project_id'],
@@ -283,6 +295,14 @@ class ListenersController(base.BaseController):
         vip_address = vip_db.ip_address
         self._validate_cidr_compatible_with_vip(vip_address, allowed_cidrs)
 
+        if listener_protocol == constants.PROTOCOL_TERMINATED_HTTPS:
+            # Validate TLS version list
+            validate.check_tls_version_list(listener_dict['tls_versions'])
+            # Validate TLS versions against minimum
+            validate.check_tls_version_min(listener_dict['tls_versions'])
+            # Validate ALPN protocol list
+            validate.check_alpn_protocols(listener_dict['alpn_protocols'])
+
         try:
             db_listener = self.repositories.listener.create(
                 lock_session, **listener_dict)
@@ -307,9 +327,9 @@ class ListenersController(base.BaseController):
                 raise exceptions.DuplicateListenerEntry(
                     protocol=listener_dict.get('protocol'),
                     port=listener_dict.get('protocol_port'))
-        except odb_exceptions.DBError:
+        except odb_exceptions.DBError as e:
             raise exceptions.InvalidOption(value=listener_dict.get('protocol'),
-                                           option='protocol')
+                                           option='protocol') from e
 
     @wsme_pecan.wsexpose(listener_types.ListenerRootResponse,
                          body=listener_types.ListenerRootPOST, status_code=201)
@@ -417,12 +437,13 @@ class ListenersController(base.BaseController):
             raise exceptions.ValidationException(
                 detail='No listener object supplied.')
 
-        # Check for UDP compatibility
-        if (db_listener.protocol == constants.PROTOCOL_UDP and
+        # Check for UDP/SCTP compatibility
+        if (db_listener.protocol in (constants.PROTOCOL_UDP,
+                                     lib_consts.PROTOCOL_SCTP) and
                 self._is_tls_or_insert_header(listener.to_dict())):
             raise exceptions.ValidationException(detail=_(
                 "%s protocol listener does not support TLS or header "
-                "insertion.") % constants.PROTOCOL_UDP)
+                "insertion.") % db_listener.protocol)
 
         # Check for certs when not TERMINATED_HTTPS
         if (db_listener.protocol != constants.PROTOCOL_TERMINATED_HTTPS and
@@ -480,6 +501,25 @@ class ListenersController(base.BaseController):
             self._validate_cidr_compatible_with_vip(
                 vip_address, listener.allowed_cidrs)
 
+        # Check TLS cipher prohibit list
+        if listener.tls_ciphers:
+            rejected_ciphers = validate.check_cipher_prohibit_list(
+                listener.tls_ciphers)
+            if rejected_ciphers:
+                raise exceptions.ValidationException(detail=_(
+                    'The following ciphers have been prohibited by an '
+                    'administrator: ' + ', '.join(rejected_ciphers)))
+
+        if listener.tls_versions is not wtypes.Unset:
+            # Validate TLS version list
+            validate.check_tls_version_list(listener.tls_versions)
+            # Validate TLS versions against minimum
+            validate.check_tls_version_min(listener.tls_versions)
+
+        if listener.alpn_protocols is not wtypes.Unset:
+            # Validate ALPN protocol list
+            validate.check_alpn_protocols(listener.alpn_protocols)
+
     def _set_default_on_none(self, listener):
         """Reset settings to their default values if None/null was passed in
 
@@ -507,6 +547,14 @@ class ListenersController(base.BaseController):
                 CONF.haproxy_amphora.timeout_tcp_inspect)
         if listener.client_authentication is None:
             listener.client_authentication = constants.CLIENT_AUTH_NONE
+        if listener.tls_ciphers is None:
+            listener.tls_ciphers = CONF.api_settings.default_listener_ciphers
+        if listener.tls_versions is None:
+            listener.tls_versions = (
+                CONF.api_settings.default_listener_tls_versions)
+        if listener.alpn_protocols is None:
+            listener.alpn_protocols = (
+                CONF.api_settings.default_listener_alpn_protocols)
 
     @wsme_pecan.wsexpose(listener_types.ListenerRootResponse, wtypes.text,
                          body=listener_types.ListenerRootPUT, status_code=200)
@@ -616,7 +664,7 @@ class StatisticsController(base.BaseController, stats.StatsMixin):
     RBAC_TYPE = constants.RBAC_LISTENER
 
     def __init__(self, listener_id):
-        super(StatisticsController, self).__init__()
+        super().__init__()
         self.id = listener_id
 
     @wsme_pecan.wsexpose(listener_types.StatisticsRootResponse, wtypes.text,
